@@ -33,12 +33,13 @@ class FarosClient:
         to the app handler
 
         :param dict event: object with properties
-        :param str api_url: Faros service api url to query against
+        :param str api_url: Faros service url to run api calls on
 
         :returns: instance of the Faros client
         :rtype: FarosClient
         """
-        return cls(event["farosToken"], api_url)
+
+        return cls(event["farosToken"], event.get("farosApiUrl", api_url))
 
     def graphql_execute(self, query, variables=None):
         """
